/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import * as beet from '@metaplex-foundation/beet';
export declare type MerkleDistributorArgs = {
    base: web3.PublicKey;
    bump: number;
    root: number[];
    temporal: web3.PublicKey;
};
export declare const merkleDistributorDiscriminator: number[];
export declare class MerkleDistributor implements MerkleDistributorArgs {
    readonly base: web3.PublicKey;
    readonly bump: number;
    readonly root: number[];
    readonly temporal: web3.PublicKey;
    private constructor();
    static fromArgs(args: MerkleDistributorArgs): MerkleDistributor;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [MerkleDistributor, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<MerkleDistributor>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<{
        bump: any;
        accountDiscriminator: any;
        root: any;
        base: any;
        temporal: any;
    }>;
    static deserialize(buf: Buffer, offset?: number): [MerkleDistributor, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        base: string;
        bump: number;
        root: number[];
        temporal: string;
    };
}
export declare const merkleDistributorBeet: beet.BeetStruct<MerkleDistributor, MerkleDistributorArgs & {
    accountDiscriminator: number[];
}>;
