"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorFromName = exports.errorFromCode = exports.BumpSeedNotInHashMapError = exports.MustUseOfficialCandyMachineError = exports.InvalidClaimBumpError = exports.NumericalOverflowError = exports.TemporalMismatchError = exports.OwnerMismatchError = exports.UnauthorizedError = exports.DropAlreadyClaimedError = exports.InvalidProofError = void 0;
const createErrorFromCodeLookup = new Map();
const createErrorFromNameLookup = new Map();
class InvalidProofError extends Error {
    constructor() {
        super('Invalid Merkle proof.');
        this.code = 0x1770;
        this.name = 'InvalidProof';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, InvalidProofError);
        }
    }
}
exports.InvalidProofError = InvalidProofError;
createErrorFromCodeLookup.set(0x1770, () => new InvalidProofError());
createErrorFromNameLookup.set('InvalidProof', () => new InvalidProofError());
class DropAlreadyClaimedError extends Error {
    constructor() {
        super('Drop already claimed.');
        this.code = 0x1771;
        this.name = 'DropAlreadyClaimed';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, DropAlreadyClaimedError);
        }
    }
}
exports.DropAlreadyClaimedError = DropAlreadyClaimedError;
createErrorFromCodeLookup.set(0x1771, () => new DropAlreadyClaimedError());
createErrorFromNameLookup.set('DropAlreadyClaimed', () => new DropAlreadyClaimedError());
class UnauthorizedError extends Error {
    constructor() {
        super('Account is not authorized to execute this instruction');
        this.code = 0x1772;
        this.name = 'Unauthorized';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, UnauthorizedError);
        }
    }
}
exports.UnauthorizedError = UnauthorizedError;
createErrorFromCodeLookup.set(0x1772, () => new UnauthorizedError());
createErrorFromNameLookup.set('Unauthorized', () => new UnauthorizedError());
class OwnerMismatchError extends Error {
    constructor() {
        super('Token account owner did not match intended owner');
        this.code = 0x1773;
        this.name = 'OwnerMismatch';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, OwnerMismatchError);
        }
    }
}
exports.OwnerMismatchError = OwnerMismatchError;
createErrorFromCodeLookup.set(0x1773, () => new OwnerMismatchError());
createErrorFromNameLookup.set('OwnerMismatch', () => new OwnerMismatchError());
class TemporalMismatchError extends Error {
    constructor() {
        super('Temporal signer did not match distributor');
        this.code = 0x1774;
        this.name = 'TemporalMismatch';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, TemporalMismatchError);
        }
    }
}
exports.TemporalMismatchError = TemporalMismatchError;
createErrorFromCodeLookup.set(0x1774, () => new TemporalMismatchError());
createErrorFromNameLookup.set('TemporalMismatch', () => new TemporalMismatchError());
class NumericalOverflowError extends Error {
    constructor() {
        super('Numerical Overflow');
        this.code = 0x1775;
        this.name = 'NumericalOverflow';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, NumericalOverflowError);
        }
    }
}
exports.NumericalOverflowError = NumericalOverflowError;
createErrorFromCodeLookup.set(0x1775, () => new NumericalOverflowError());
createErrorFromNameLookup.set('NumericalOverflow', () => new NumericalOverflowError());
class InvalidClaimBumpError extends Error {
    constructor() {
        super('Invalid Claim Bump');
        this.code = 0x1776;
        this.name = 'InvalidClaimBump';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, InvalidClaimBumpError);
        }
    }
}
exports.InvalidClaimBumpError = InvalidClaimBumpError;
createErrorFromCodeLookup.set(0x1776, () => new InvalidClaimBumpError());
createErrorFromNameLookup.set('InvalidClaimBump', () => new InvalidClaimBumpError());
class MustUseOfficialCandyMachineError extends Error {
    constructor() {
        super('Gumdrop only supports the official Metaplex Candy machine contracts');
        this.code = 0x1777;
        this.name = 'MustUseOfficialCandyMachine';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, MustUseOfficialCandyMachineError);
        }
    }
}
exports.MustUseOfficialCandyMachineError = MustUseOfficialCandyMachineError;
createErrorFromCodeLookup.set(0x1777, () => new MustUseOfficialCandyMachineError());
createErrorFromNameLookup.set('MustUseOfficialCandyMachine', () => new MustUseOfficialCandyMachineError());
class BumpSeedNotInHashMapError extends Error {
    constructor() {
        super('Bump seed not in hash map');
        this.code = 0x1778;
        this.name = 'BumpSeedNotInHashMap';
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, BumpSeedNotInHashMapError);
        }
    }
}
exports.BumpSeedNotInHashMapError = BumpSeedNotInHashMapError;
createErrorFromCodeLookup.set(0x1778, () => new BumpSeedNotInHashMapError());
createErrorFromNameLookup.set('BumpSeedNotInHashMap', () => new BumpSeedNotInHashMapError());
function errorFromCode(code) {
    const createError = createErrorFromCodeLookup.get(code);
    return createError != null ? createError() : null;
}
exports.errorFromCode = errorFromCode;
function errorFromName(name) {
    const createError = createErrorFromNameLookup.get(name);
    return createError != null ? createError() : null;
}
exports.errorFromName = errorFromName;
//# sourceMappingURL=index.js.map